Module: Hyrax

Extended by:
ActiveSupport::Autoload
Defined in:
lib/hyrax.rb,
lib/hyrax/name.rb,
lib/hyrax/arkivo.rb,
lib/hyrax/engine.rb,
lib/hyrax/errors.rb,
lib/hyrax/schema.rb,
lib/hyrax/zotero.rb,
lib/hyrax/indexer.rb,
lib/hyrax/version.rb,
lib/hyrax/publisher.rb,
app/forms/hyrax/forms.rb,
app/models/hyrax/base.rb,
app/models/hyrax/work.rb,
lib/hyrax/deprecation.rb,
lib/hyrax/event_store.rb,
lib/hyrax/form_fields.rb,
app/models/hyrax/event.rb,
app/models/hyrax/group.rb,
app/models/hyrax/lease.rb,
lib/hyrax/arkivo/actor.rb,
lib/hyrax/search_state.rb,
lib/hyrax/transactions.rb,
app/services/hyrax/noid.rb,
lib/hyrax/arkivo/config.rb,
lib/hyrax/configuration.rb,
lib/hyrax/resource_name.rb,
lib/hyrax/resource_sync.rb,
lib/hyrax/role_registry.rb,
lib/hyrax/zotero/config.rb,
app/models/hyrax/embargo.rb,
app/models/hyrax/feature.rb,
app/models/hyrax/download.rb,
app/models/hyrax/file_set.rb,
app/models/hyrax/pageview.rb,
app/models/hyrax/redirect.rb,
app/models/hyrax/resource.rb,
lib/hyrax/collection_name.rb,
lib/hyrax/model_decorator.rb,
app/models/hyrax/operation.rb,
app/models/hyrax/statistic.rb,
app/forms/hyrax/forms/lease.rb,
app/indexers/hyrax/indexers.rb,
app/models/hyrax/change_set.rb,
app/models/hyrax/permission.rb,
app/models/hyrax/riiif/file.rb,
app/models/hyrax/riiif/file.rb,
app/services/hyrax/lockable.rb,
app/services/hyrax/workflow.rb,
app/values/hyrax/chart_data.rb,
lib/hyrax/redis_event_store.rb,
app/services/hyrax/analytics.rb,
app/services/hyrax/callbacks.rb,
app/services/hyrax/listeners.rb,
app/services/hyrax/microdata.rb,
lib/hyrax/specs/spy_listener.rb,
app/forms/hyrax/forms/embargo.rb,
app/helpers/hyrax/iiif_helper.rb,
app/jobs/hyrax/grant_edit_job.rb,
app/jobs/hyrax/grant_read_job.rb,
app/models/hyrax/contact_form.rb,
app/renderers/hyrax/renderers.rb,
lib/hyrax/controller_resource.rb,
lib/hyrax/rubocop/custom_cops.rb,
app/helpers/hyrax/lease_helper.rb,
app/helpers/hyrax/works_helper.rb,
app/jobs/hyrax/application_job.rb,
app/jobs/hyrax/revoke_edit_job.rb,
app/models/hyrax/file_metadata.rb,
app/models/hyrax/redirect_path.rb,
app/models/hyrax/uploaded_file.rb,
app/models/hyrax/virus_scanner.rb,
app/services/hyrax/child_types.rb,
app/services/hyrax/institution.rb,
app/builders/hyrax/form_builder.rb,
app/forms/hyrax/forms/work_form.rb,
app/helpers/hyrax/charts_helper.rb,
app/helpers/hyrax/facets_helper.rb,
app/helpers/hyrax/trophy_helper.rb,
app/indexers/hyrax/work_indexer.rb,
app/models/hyrax/access_control.rb,
app/models/hyrax/counter_metric.rb,
app/models/hyrax/group_behavior.rb,
app/models/hyrax/model_registry.rb,
app/presenters/hyrax/file_usage.rb,
app/presenters/hyrax/model_icon.rb,
app/presenters/hyrax/work_usage.rb,
app/services/hyrax/form_factory.rb,
app/services/hyrax/lock_manager.rb,
app/services/hyrax/solr_service.rb,
app/services/hyrax/time_service.rb,
app/forms/hyrax/forms/permission.rb,
app/helpers/hyrax/ability_helper.rb,
app/helpers/hyrax/embargo_helper.rb,
app/jobs/hyrax/queued_delete_job.rb,
app/mailers/hyrax/contact_mailer.rb,
app/models/concerns/hyrax/naming.rb,
app/models/hyrax/collection_type.rb,
app/models/hyrax/orcid_validator.rb,
app/models/hyrax/pcdm_collection.rb,
app/presenters/hyrax/model_proxy.rb,
app/services/hyrax/analytics/ga4.rb,
app/services/hyrax/lease_manager.rb,
app/services/hyrax/lease_service.rb,
app/services/hyrax/schema_loader.rb,
app/utils/hyrax/data_maintenance.rb,
app/utils/hyrax/test_data_seeder.rb,
lib/hyrax/arkivo/metadata_munger.rb,
lib/hyrax/transactions/container.rb,
app/models/concerns/hyrax/ability.rb,
app/models/hyrax/avatar_validator.rb,
app/services/hyrax/custom_queries.rb,
app/services/hyrax/graph_exporter.rb,
app/services/hyrax/permalink_path.rb,
app/services/hyrax/search_service.rb,
app/services/hyrax/visibility_map.rb,
lib/hyrax/administrative_set_name.rb,
lib/hyrax/arkivo/schema_validator.rb,
lib/hyrax/controlled_vocabularies.rb,
lib/hyrax/transactions/steps/save.rb,
app/actors/hyrax/actors/base_actor.rb,
app/actors/hyrax/actors/file_actor.rb,
app/actors/hyrax/actors/null_actor.rb,
app/actors/hyrax/actors/terminator.rb,
app/builders/hyrax/manifest_helper.rb,
app/controllers/concerns/hyrax/api.rb,
app/helpers/hyrax/permalink_helper.rb,
app/helpers/hyrax/work_form_helper.rb,
app/helpers/hyrax/workflows_helper.rb,
app/jobs/hyrax/queued_indexing_job.rb,
app/models/hyrax/version_committer.rb,
app/services/hyrax/contextual_path.rb,
app/services/hyrax/derivative_path.rb,
app/services/hyrax/embargo_manager.rb,
app/services/hyrax/embargo_service.rb,
app/services/hyrax/license_service.rb,
app/services/hyrax/resource_status.rb,
lib/hyrax/health_checks/solr_check.rb,
lib/hyrax/transactions/transaction.rb,
lib/hyrax/transactions/work_create.rb,
lib/hyrax/transactions/work_update.rb,
lib/hyrax/valkyrie_can_can_adapter.rb,
app/actors/hyrax/actors/environment.rb,
app/actors/hyrax/actors/lease_actor.rb,
app/actors/hyrax/actors/model_actor.rb,
app/controllers/hyrax/my_controller.rb,
app/forms/hyrax/forms/file_set_form.rb,
app/forms/hyrax/forms/resource_form.rb,
app/helpers/hyrax/attributes_helper.rb,
app/helpers/hyrax/membership_helper.rb,
app/indexers/hyrax/file_set_indexer.rb,
app/indexers/hyrax/indexes_workflow.rb,
app/indexers/hyrax/valkyrie_indexer.rb,
app/models/hyrax/administrative_set.rb,
app/presenters/hyrax/displays_image.rb,
app/presenters/hyrax/menu_presenter.rb,
app/services/hyrax/analytics/google.rb,
app/services/hyrax/analytics/matomo.rb,
app/services/hyrax/curation_concern.rb,
app/services/hyrax/location_service.rb,
app/services/hyrax/m3_schema_loader.rb,
app/services/hyrax/redirects_lookup.rb,
lib/hyrax/active_fedora_dummy_model.rb,
lib/hyrax/transactions/work_destroy.rb,
app/forms/hyrax/forms/admin_set_form.rb,
app/helpers/hyrax/batch_edits_helper.rb,
app/helpers/hyrax/citations_behavior.rb,
app/helpers/hyrax/collections_helper.rb,
app/helpers/hyrax/permissions_helper.rb,
app/indexers/hyrax/admin_set_indexer.rb,
app/models/hyrax/permission_template.rb,
app/models/hyrax/riiif/file_resolver.rb,
app/models/hyrax/riiif/file_resolver.rb,
app/presenters/hyrax/lease_presenter.rb,
app/services/hyrax/admin_set_service.rb,
app/services/hyrax/analytics/results.rb,
app/services/hyrax/authority_service.rb,
app/services/hyrax/database_migrator.rb,
app/services/hyrax/m3_profile_editor.rb,
app/services/hyrax/messenger_service.rb,
app/services/hyrax/qa_select_service.rb,
app/services/hyrax/visibility_reader.rb,
app/services/hyrax/visibility_writer.rb,
app/services/hyrax/work_form_service.rb,
app/services/hyrax/working_directory.rb,
app/utils/hyrax/required_data_seeder.rb,
app/actors/hyrax/actors/embargo_actor.rb,
app/forms/hyrax/forms/batch_edit_form.rb,
app/forms/hyrax/forms/collection_form.rb,
app/forms/hyrax/forms/work_lease_form.rb,
app/helpers/hyrax/blacklight_override.rb,
app/helpers/hyrax/contact_form_helper.rb,
app/indexers/hyrax/collection_indexer.rb,
app/models/concerns/hyrax/ar_resource.rb,
app/models/concerns/hyrax/embargoable.rb,
app/models/concerns/hyrax/flexibility.rb,
app/models/concerns/hyrax/permissions.rb,
app/models/concerns/hyrax/serializers.rb,
app/models/concerns/hyrax/virus_check.rb,
app/models/concerns/hyrax/with_events.rb,
app/models/hyrax/workflow_action_info.rb,
app/presenters/hyrax/displays_content.rb,
app/presenters/hyrax/permission_badge.rb,
app/presenters/hyrax/trophy_presenter.rb,
app/services/hyrax/analytics/ga4/base.rb,
app/services/hyrax/identifier/builder.rb,
app/services/hyrax/indexes_thumbnails.rb,
app/services/hyrax/local_file_service.rb,
app/services/hyrax/permission_manager.rb,
app/services/hyrax/solr_query_service.rb,
app/services/hyrax/user_stat_importer.rb,
app/services/hyrax/versioning_service.rb,
app/services/hyrax/work_query_service.rb,
lib/hyrax/transactions/steps/validate.rb,
app/actors/hyrax/actors/abstract_actor.rb,
app/actors/hyrax/actors/file_set_actor.rb,
app/connections/hyrax/clean_connection.rb,
app/controllers/hyrax/pages_controller.rb,
app/controllers/hyrax/stats_controller.rb,
app/controllers/hyrax/users_controller.rb,
app/forms/hyrax/forms/admin/appearance.rb,
app/forms/hyrax/forms/pcdm_object_form.rb,
app/helpers/hyrax/content_block_helper.rb,
app/helpers/hyrax/file_set_form_helper.rb,
app/helpers/hyrax/redirects_tab_helper.rb,
app/models/concerns/hyrax/in_admin_set.rb,
app/models/concerns/hyrax/nested_works.rb,
app/models/concerns/hyrax/suppressible.rb,
app/presenters/hyrax/annotates_content.rb,
app/presenters/hyrax/embargo_presenter.rb,
app/presenters/hyrax/presenter_factory.rb,
app/presenters/hyrax/twitter_presenter.rb,
app/presenters/hyrax/version_presenter.rb,
app/services/hyrax/access_control_list.rb,
app/services/hyrax/collections_service.rb,
app/services/hyrax/persist_derivatives.rb,
app/services/hyrax/restriction_service.rb,
lib/generators/hyrax/install_generator.rb,
lib/hyrax/transactions/file_set_update.rb,
app/controllers/hyrax/leases_controller.rb,
app/controllers/hyrax/static_controller.rb,
app/forms/hyrax/forms/batch_upload_form.rb,
app/forms/hyrax/forms/work_embargo_form.rb,
app/helpers/hyrax/hyrax_helper_behavior.rb,
app/models/concerns/hyrax/core_metadata.rb,
app/models/concerns/hyrax/proxy_deposit.rb,
app/models/concerns/hyrax/work_behavior.rb,
app/models/hyrax/batch_create_operation.rb,
app/presenters/hyrax/file_set_presenter.rb,
app/presenters/hyrax/homepage_presenter.rb,
app/presenters/hyrax/presenter_renderer.rb,
app/presenters/hyrax/workflow_presenter.rb,
app/search_builders/hyrax/single_result.rb,
app/search_builders/hyrax/work_relation.rb,
app/services/hyrax/analytics/ga4/events.rb,
app/services/hyrax/analytics/ga4/visits.rb,
app/services/hyrax/file_set_csv_service.rb,
app/services/hyrax/identifier/registrar.rb,
app/services/hyrax/list_source_exporter.rb,
app/services/hyrax/simple_schema_loader.rb,
app/services/hyrax/statistics/over_time.rb,
app/services/hyrax/visibility_intention.rb,
app/services/hyrax/work_uploads_handler.rb,
app/validators/hyrax/redirect_validator.rb,
lib/hyrax/transactions/admin_set_create.rb,
lib/hyrax/transactions/admin_set_update.rb,
lib/hyrax/transactions/apply_change_set.rb,
lib/hyrax/transactions/file_set_destroy.rb,
app/channels/hyrax/notifications_channel.rb,
app/controllers/hyrax/uploads_controller.rb,
app/indexers/hyrax/deep_indexing_service.rb,
app/indexers/hyrax/valkyrie_work_indexer.rb,
app/jobs/hyrax/grant_edit_to_members_job.rb,
app/jobs/hyrax/grant_read_to_members_job.rb,
app/models/concerns/hyrax/basic_metadata.rb,
app/presenters/hyrax/admin_set_presenter.rb,
app/presenters/hyrax/presents_attributes.rb,
app/presenters/hyrax/transfers_presenter.rb,
app/presenters/hyrax/work_show_presenter.rb,
app/search_builders/hyrax/filter_by_type.rb,
app/search_builders/hyrax/search_builder.rb,
app/search_builders/hyrax/search_filters.rb,
app/services/hyrax/file_set_file_service.rb,
app/services/hyrax/file_set_type_service.rb,
app/services/hyrax/form_metadata_service.rb,
app/services/hyrax/identifier/dispatcher.rb,
app/services/hyrax/statistics/term_query.rb,
app/services/hyrax/virus_checker_service.rb,
app/services/hyrax/visibility_propagator.rb,
lib/hyrax/arkivo/create_subscription_job.rb,
lib/hyrax/specs/shared_specs/simple_work.rb,
lib/hyrax/transactions/admin_set_destroy.rb,
lib/hyrax/transactions/collection_create.rb,
lib/hyrax/transactions/collection_update.rb,
lib/hyrax/valkyrie_simple_path_generator.rb,
app/actors/hyrax/actors/add_to_work_actor.rb,
app/actors/hyrax/actors/apply_order_actor.rb,
app/controllers/hyrax/my/works_controller.rb,
app/controllers/hyrax/trophies_controller.rb,
app/indexers/hyrax/basic_metadata_indexer.rb,
app/models/hyrax/valkyrie_global_id_proxy.rb,
app/presenters/hyrax/collection_presenter.rb,
app/presenters/hyrax/displays_transcripts.rb,
app/presenters/hyrax/page_title_decorator.rb,
app/services/hyrax/resource_types_service.rb,
app/services/hyrax/statistics/works/count.rb,
app/services/hyrax/thumbnail_path_service.rb,
lib/generators/hyrax/collection_generator.rb,
lib/hyrax/transactions/collection_destroy.rb,
app/controllers/concerns/hyrax/breadcrumbs.rb,
app/controllers/concerns/hyrax/collections.rb,
app/controllers/hyrax/api/items_controller.rb,
app/controllers/hyrax/citations_controller.rb,
app/controllers/hyrax/dashboard_controller.rb,
app/controllers/hyrax/downloads_controller.rb,
app/controllers/hyrax/embargoes_controller.rb,
app/controllers/hyrax/file_sets_controller.rb,
app/controllers/hyrax/my/shares_controller.rb,
app/controllers/hyrax/redirects_controller.rb,
app/controllers/hyrax/transfers_controller.rb,
app/forms/hyrax/forms/pcdm_collection_form.rb,
app/forms/hyrax/forms/workflow_action_form.rb,
app/helpers/hyrax/permission_levels_helper.rb,
app/indexers/hyrax/pcdm_collection_indexer.rb,
app/presenters/hyrax/admin/users_presenter.rb,
app/presenters/hyrax/admin_stats_presenter.rb,
app/presenters/hyrax/select_type_presenter.rb,
app/presenters/hyrax/stats_usage_presenter.rb,
app/services/hyrax/analytics/google/events.rb,
app/services/hyrax/analytics/google/visits.rb,
app/services/hyrax/listeners/file_listener.rb,
app/services/hyrax/statistics/system_stats.rb,
app/services/hyrax/tolerant_select_service.rb,
app/services/hyrax/works/migration_service.rb,
app/uploaders/hyrax/uploaded_file_uploader.rb,
lib/generators/hyrax/sample_data_generator.rb,
lib/hyrax/controlled_vocabularies/location.rb,
lib/hyrax/resource_sync/change_list_writer.rb,
lib/hyrax/transactions/steps/add_file_sets.rb,
lib/hyrax/transactions/steps/add_to_parent.rb,
app/actors/hyrax/actors/featured_work_actor.rb,
app/controllers/hyrax/api/zotero_controller.rb,
app/controllers/hyrax/depositors_controller.rb,
app/controllers/hyrax/operations_controller.rb,
app/helpers/hyrax/dashboard_helper_behavior.rb,
app/jobs/concerns/hyrax/queued_job_behavior.rb,
app/jobs/hyrax/revoke_edit_from_members_job.rb,
app/models/concerns/hyrax/file_set/indexing.rb,
app/models/concerns/hyrax/file_set/querying.rb,
app/models/concerns/hyrax/file_set_behavior.rb,
app/models/hyrax/default_administrative_set.rb,
app/models/hyrax/permission_template_access.rb,
app/presenters/hyrax/inspect_work_presenter.rb,
app/presenters/hyrax/user_profile_presenter.rb,
app/presenters/hyrax/version_list_presenter.rb,
app/search_builders/hyrax/filter_suppressed.rb,
app/search_builders/hyrax/my/search_builder.rb,
app/services/hyrax/abstract_message_service.rb,
app/services/hyrax/admin_set_create_service.rb,
app/services/hyrax/admin_set_member_service.rb,
app/services/hyrax/change_depositor_service.rb,
app/services/hyrax/default_middleware_stack.rb,
app/services/hyrax/edit_permissions_service.rb,
app/services/hyrax/manifest_builder_service.rb,
app/services/hyrax/redirect_path_normalizer.rb,
app/services/hyrax/rights_statement_service.rb,
app/services/hyrax/statistics/query_service.rb,
app/services/hyrax/workflow/activate_object.rb,
app/services/hyrax/workflow/workflow_schema.rb,
app/actors/hyrax/actors/attach_members_actor.rb,
app/channels/hyrax/application_cable/channel.rb,
app/controllers/hyrax/admin/stats_controller.rb,
app/controllers/hyrax/admin/users_controller.rb,
app/controllers/hyrax/batch_edits_controller.rb,
app/controllers/hyrax/collections_controller.rb,
app/controllers/hyrax/permissions_controller.rb,
app/controllers/hyrax/transcripts_controller.rb,
app/forms/concerns/hyrax/permission_behavior.rb,
app/indexers/concerns/hyrax/location_indexer.rb,
app/indexers/concerns/hyrax/workflow_indexer.rb,
app/indexers/hyrax/indexers/file_set_indexer.rb,
app/indexers/hyrax/indexers/resource_indexer.rb,
app/indexers/hyrax/valkyrie_file_set_indexer.rb,
app/models/hyrax/collection_type_participant.rb,
app/presenters/hyrax/fixity_status_presenter.rb,
app/presenters/hyrax/iiif_manifest_presenter.rb,
app/presenters/hyrax/missing_method_behavior.rb,
app/services/hyrax/collection_member_service.rb,
app/services/hyrax/workflow/method_generator.rb,
app/services/hyrax/workflow/permission_query.rb,
app/services/hyrax/workflow/workflow_factory.rb,
app/validators/hyrax/has_one_title_validator.rb,
lib/hyrax/resource_sync/resource_list_writer.rb,
lib/hyrax/transactions/file_metadata_destroy.rb,
lib/hyrax/transactions/steps/delete_resource.rb,
app/actors/hyrax/actors/ordered_members_actor.rb,
app/actors/hyrax/actors/transactional_request.rb,
app/controllers/hyrax/contact_form_controller.rb,
app/forms/concerns/hyrax/transcripts_behavior.rb,
app/forms/hyrax/forms/administrative_set_form.rb,
app/indexers/concerns/hyrax/thumbnail_indexer.rb,
app/indexers/hyrax/administrative_set_indexer.rb,
app/indexers/hyrax/indexers/redirects_indexer.rb,
app/jobs/hyrax/propagate_change_depositor_job.rb,
app/models/concerns/hyrax/collection_behavior.rb,
app/models/concerns/hyrax/human_readable_type.rb,
app/presenters/hyrax/dashboard/user_presenter.rb,
app/presenters/hyrax/google_scholar_presenter.rb,
app/presenters/hyrax/member_presenter_factory.rb,
app/search_builders/hyrax/work_search_builder.rb,
app/services/hyrax/analytics/ga4/events_daily.rb,
app/services/hyrax/analytics/ga4/visits_daily.rb,
app/services/hyrax/authority_rendering_helper.rb,
app/services/hyrax/collections/search_service.rb,
app/services/hyrax/iiif_authorization_service.rb,
app/services/hyrax/import_url_failure_service.rb,
app/services/hyrax/quick_classification_query.rb,
app/services/hyrax/solr_query_builder_service.rb,
app/services/hyrax/statistics/users/over_time.rb,
app/services/hyrax/statistics/works/over_time.rb,
app/services/hyrax/workflow/deactivate_object.rb,
app/services/hyrax/workflow/workflow_importer.rb,
app/utils/hyrax/test_data_seeders/user_seeder.rb,
lib/hyrax/transactions/steps/change_depositor.rb,
lib/hyrax/transactions/steps/ensure_admin_set.rb,
app/actors/hyrax/actors/cleanup_trophies_actor.rb,
app/actors/hyrax/actors/transfer_request_actor.rb,
app/controllers/hyrax/batch_uploads_controller.rb,
app/controllers/hyrax/fixity_checks_controller.rb,
app/controllers/hyrax/my/highlights_controller.rb,
app/controllers/hyrax/notifications_controller.rb,
app/forms/concerns/hyrax/leaseability_behavior.rb,
app/forms/hyrax/forms/permission_template_form.rb,
app/forms/hyrax/forms/resource_batch_edit_form.rb,
app/indexers/concerns/hyrax/permission_indexer.rb,
app/indexers/concerns/hyrax/visibility_indexer.rb,
app/indexers/hyrax/valkyrie_collection_indexer.rb,
app/models/concerns/hyrax/file_set/derivatives.rb,
app/models/concerns/hyrax/file_set/transcripts.rb,
app/models/concerns/hyrax/permissions/readable.rb,
app/models/concerns/hyrax/permissions/writable.rb,
app/models/concerns/hyrax/solr_document/export.rb,
app/presenters/hyrax/admin/dashboard_presenter.rb,
app/presenters/hyrax/characterization_behavior.rb,
app/presenters/hyrax/single_use_link_presenter.rb,
app/search_builders/hyrax/lease_search_builder.rb,
app/search_builders/hyrax/works_search_builder.rb,
app/services/hyrax/action/create_valkyrie_work.rb,
app/services/hyrax/derivative_bucketed_storage.rb,
app/services/hyrax/listeners/workflow_listener.rb,
app/services/hyrax/multiple_membership_checker.rb,
app/services/hyrax/work_resource_query_service.rb,
app/services/hyrax/work_thumbnail_path_service.rb,
app/services/hyrax/workflow/actionable_objects.rb,
app/services/hyrax/works/managed_works_service.rb,
lib/hyrax/resource_sync/capability_list_writer.rb,
lib/hyrax/transactions/steps/set_modified_date.rb,
app/actors/hyrax/actors/cleanup_file_sets_actor.rb,
app/actors/hyrax/actors/create_with_files_actor.rb,
app/actors/hyrax/actors/default_admin_set_actor.rb,
app/channels/hyrax/application_cable/connection.rb,
app/controllers/hyrax/admin/features_controller.rb,
app/controllers/hyrax/content_blocks_controller.rb,
app/controllers/hyrax/featured_works_controller.rb,
app/controllers/hyrax/my/collections_controller.rb,
app/forms/concerns/hyrax/flexible_form_behavior.rb,
app/helpers/hyrax/content_block_helper_behavior.rb,
app/indexers/hyrax/indexers/pcdm_object_indexer.rb,
app/jobs/concerns/hyrax/permission_job_behavior.rb,
app/presenters/hyrax/select_type_list_presenter.rb,
app/services/hyrax/batch_create_failure_service.rb,
app/services/hyrax/batch_create_success_service.rb,
app/services/hyrax/custom_queries/find_count_by.rb,
app/services/hyrax/file_set_derivatives_service.rb,
app/services/hyrax/fixity/missing_content_error.rb,
app/services/hyrax/fixity_check_failure_service.rb,
app/services/hyrax/listeners/acl_index_listener.rb,
app/services/hyrax/valkyrie_persist_derivatives.rb,
app/services/hyrax/workflow/status_list_service.rb,
app/utils/hyrax/data_destroyers/stats_destroyer.rb,
lib/hyrax/transactions/steps/add_to_collections.rb,
app/controllers/concerns/hyrax/manages_embargoes.rb,
app/controllers/hyrax/admin/workflows_controller.rb,
app/controllers/hyrax/dashboard/works_controller.rb,
app/forms/hyrax/forms/admin/collection_type_form.rb,
app/helpers/hyrax/citations_behaviors/formatters.rb,
app/models/concerns/hyrax/solr_document/metadata.rb,
app/models/concerns/hyrax/solr_document_behavior.rb,
app/presenters/hyrax/admin_set_options_presenter.rb,
app/presenters/hyrax/composite_presenter_factory.rb,
app/renderers/hyrax/renderers/attribute_renderer.rb,
app/search_builders/hyrax/abstract_type_relation.rb,
app/search_builders/hyrax/deposit_search_builder.rb,
app/search_builders/hyrax/embargo_search_builder.rb,
app/search_builders/hyrax/valkyrie_work_relation.rb,
app/services/hyrax/analytics/google/events_daily.rb,
app/services/hyrax/analytics/google/visits_daily.rb,
app/services/hyrax/caching_iiif_manifest_builder.rb,
app/services/hyrax/file_set_fixity_check_service.rb,
app/services/hyrax/find_objects_via_solr_service.rb,
app/services/hyrax/statistics/depositors/summary.rb,
app/services/hyrax/statistics/works/by_depositor.rb,
app/services/hyrax/workflow/action_taken_service.rb,
app/services/hyrax/workflow/notification_service.rb,
app/services/hyrax/workflow/permission_generator.rb,
lib/hyrax/transactions/steps/save_access_control.rb,
lib/hyrax/transactions/steps/set_user_as_creator.rb,
lib/hyrax/transactions/steps/sync_redirect_paths.rb,
lib/hyrax/transactions/steps/update_work_members.rb,
app/actors/hyrax/actors/active_fedora_to_valkyrie.rb,
app/actors/hyrax/actors/optimistic_lock_validator.rb,
app/actors/hyrax/actors/valkyrie_to_active_fedora.rb,
app/controllers/hyrax/admin/admin_sets_controller.rb,
app/controllers/hyrax/admin/strategies_controller.rb,
app/controllers/hyrax/single_use_links_controller.rb,
app/controllers/hyrax/workflow_actions_controller.rb,
app/forms/concerns/hyrax/redirects_field_behavior.rb,
app/models/concerns/hyrax/redirects_normalization.rb,
app/models/concerns/hyrax/valkyrie_lazy_migration.rb,
app/search_builders/hyrax/exposed_models_relation.rb,
app/search_builders/hyrax/file_set_search_builder.rb,
app/search_builders/hyrax/my/works_search_builder.rb,
app/services/hyrax/file_set_visibility_propagator.rb,
app/services/hyrax/permission_template_applicator.rb,
app/services/hyrax/resource_visibility_propagator.rb,
app/services/hyrax/statistics/file_sets/by_format.rb,
app/services/hyrax/workflow/abstract_notification.rb,
lib/hyrax/controlled_vocabulary/importer/language.rb,
lib/hyrax/resource_sync/source_description_writer.rb,
lib/hyrax/transactions/steps/delete_all_file_sets.rb,
lib/hyrax/transactions/steps/file_metadata_delete.rb,
lib/hyrax/transactions/steps/save_collection_logo.rb,
app/actors/hyrax/actors/interpret_visibility_actor.rb,
app/controllers/hyrax/admin/appearances_controller.rb,
app/forms/concerns/hyrax/based_near_field_behavior.rb,
app/forms/hyrax/forms/widgets/admin_set_visibility.rb,
app/forms/hyrax/forms/workflow_responsibility_form.rb,
app/indexers/concerns/hyrax/indexes_basic_metadata.rb,
app/models/concerns/hyrax/ability/resource_ability.rb,
app/presenters/hyrax/admin/user_activity_presenter.rb,
app/presenters/hyrax/admin/workflow_role_presenter.rb,
app/presenters/hyrax/admin_set_selection_presenter.rb,
app/presenters/hyrax/collapsable_section_presenter.rb,
app/presenters/hyrax/pcdm_member_presenter_factory.rb,
app/renderers/hyrax/renderers/configured_microdata.rb,
app/search_builders/hyrax/admin_set_search_builder.rb,
app/services/hyrax/collection_types/create_service.rb,
app/services/hyrax/collections/permissions_service.rb,
app/services/hyrax/repository_fixity_check_service.rb,
app/services/hyrax/visibility_intention_applicator.rb,
app/services/hyrax/workflow/deposited_notification.rb,
app/services/hyrax/workflow/notification_generator.rb,
lib/hyrax/transactions/steps/delete_access_control.rb,
lib/hyrax/transactions/steps/remove_redirect_paths.rb,
lib/hyrax/transactions/steps/set_default_admin_set.rb,
lib/hyrax/transactions/steps/set_user_as_depositor.rb,
app/components/hyrax/dropdown_facet_field_component.rb,
app/controllers/concerns/hyrax/admin/stats_behavior.rb,
app/controllers/hyrax/dashboard/profiles_controller.rb,
app/forms/concerns/hyrax/deposit_agreement_behavior.rb,
app/helpers/hyrax/citations_behaviors/name_behavior.rb,
app/indexers/concerns/hyrax/indexes_linked_metadata.rb,
app/indexers/hyrax/indexers/pcdm_collection_indexer.rb,
app/models/concerns/hyrax/ability/admin_set_ability.rb,
app/models/concerns/hyrax/file_set/belongs_to_works.rb,
app/models/concerns/hyrax/file_set/characterization.rb,
app/models/concerns/hyrax/with_embargoes_and_leases.rb,
app/presenters/hyrax/admin/workflow_roles_presenter.rb,
app/search_builders/hyrax/collection_search_builder.rb,
app/services/hyrax/change_content_depositor_service.rb,
app/services/hyrax/custom_queries/find_ids_by_model.rb,
app/services/hyrax/listeners/file_metadata_listener.rb,
app/services/hyrax/listeners/proxy_deposit_listener.rb,
app/services/hyrax/statistics/collections/over_time.rb,
app/services/hyrax/workflow/grant_edit_to_depositor.rb,
app/services/hyrax/workflow/grant_read_to_depositor.rb,
app/services/hyrax/workflow/state_machine_generator.rb,
app/services/hyrax/workflow/workflow_action_service.rb,
app/utils/hyrax/test_data_seeders/collection_seeder.rb,
lib/hyrax/controlled_vocabulary/importer/downloader.rb,
lib/hyrax/transactions/steps/remove_from_membership.rb,
lib/hyrax/transactions/steps/save_collection_banner.rb,
app/actors/hyrax/actors/collections_membership_actor.rb,
app/controllers/concerns/hyrax/breadcrumbs_for_works.rb,
app/controllers/hyrax/featured_work_lists_controller.rb,
app/forms/concerns/hyrax/contained_in_works_behavior.rb,
app/forms/hyrax/forms/dashboard/nest_collection_form.rb,
app/forms/hyrax/forms/failed_submission_form_wrapper.rb,
app/helpers/hyrax/citations_behaviors/title_behavior.rb,
app/models/concerns/hyrax/ability/collection_ability.rb,
app/services/hyrax/collection_thumbnail_path_service.rb,
app/services/hyrax/custom_queries/find_by_date_range.rb,
app/services/hyrax/custom_queries/find_file_metadata.rb,
app/services/hyrax/flexible_schema_validator_service.rb,
app/services/hyrax/listeners/member_cleanup_listener.rb,
app/services/hyrax/listeners/metadata_index_listener.rb,
app/services/hyrax/listeners/trophy_cleanup_listener.rb,
app/services/hyrax/statistics/valkyrie_query_service.rb,
app/services/hyrax/statistics/works/by_resource_type.rb,
app/services/hyrax/workflow/sipity_actions_generator.rb,
app/validators/hyrax/collection_membership_validator.rb,
app/validators/hyrax/controlled_vocabulary_validator.rb,
lib/hyrax/transactions/steps/set_collection_type_gid.rb,
app/controllers/hyrax/admin/workflow_roles_controller.rb,
app/helpers/hyrax/citations_behaviors/common_behavior.rb,
app/presenters/hyrax/select_collection_type_presenter.rb,
app/renderers/hyrax/renderers/date_attribute_renderer.rb,
app/services/hyrax/custom_queries/find_access_control.rb,
lib/hyrax/transactions/steps/delete_all_file_metadata.rb,
app/actors/hyrax/actors/create_with_remote_files_actor.rb,
app/actors/hyrax/actors/file_set_ordered_members_actor.rb,
app/controllers/concerns/hyrax/redirect_to_display_url.rb,
app/controllers/hyrax/dashboard/collections_controller.rb,
app/forms/hyrax/forms/widgets/admin_set_embargo_period.rb,
app/indexers/hyrax/indexers/administrative_set_indexer.rb,
app/presenters/hyrax/admin/repository_growth_presenter.rb,
app/presenters/hyrax/admin/repository_object_presenter.rb,
app/search_builders/hyrax/expired_lease_search_builder.rb,
app/search_builders/hyrax/filter_suppressed_with_roles.rb,
app/services/hyrax/fixity/active_fedora_fixity_service.rb,
app/services/hyrax/listeners/object_lifecycle_listener.rb,
app/services/hyrax/workflow/revoke_edit_from_depositor.rb,
lib/generators/hyrax/iiif_viewer/iiif_viewer_generator.rb,
lib/hyrax/transactions/steps/apply_permission_template.rb,
lib/hyrax/transactions/steps/check_for_empty_admin_set.rb,
lib/hyrax/transactions/steps/remove_file_set_from_work.rb,
app/actors/hyrax/actors/apply_permission_template_actor.rb,
app/controllers/concerns/hyrax/analytics_error_handling.rb,
app/controllers/concerns/hyrax/ensure_migrated_behavior.rb,
app/controllers/concerns/hyrax/flexible_schema_behavior.rb,
app/controllers/concerns/hyrax/themed_layout_controller.rb,
app/controllers/hyrax/admin/collection_types_controller.rb,
app/jobs/concerns/hyrax/members_permission_job_behavior.rb,
app/models/concerns/hyrax/ability/solr_document_ability.rb,
app/models/concerns/hyrax/solr_document/ordered_members.rb,
app/renderers/hyrax/renderers/linked_attribute_renderer.rb,
app/services/hyrax/collection_types/permissions_service.rb,
app/services/hyrax/custom_queries/find_models_by_access.rb,
app/services/hyrax/custom_queries/navigators/find_files.rb,
app/services/hyrax/ensure_well_formed_admin_set_service.rb,
app/services/hyrax/workflow/pending_review_notification.rb,
app/utils/hyrax/required_data_seeders/collection_seeder.rb,
lib/generators/hyrax/templates/config/arkivo_constraint.rb,
lib/hyrax/transactions/steps/delete_permission_template.rb,
app/controllers/concerns/hyrax/flexible_catalog_behavior.rb,
app/controllers/concerns/hyrax/works_controller_behavior.rb,
app/controllers/hyrax/admin/metadata_profiles_controller.rb,
app/controllers/hyrax/single_use_links_viewer_controller.rb,
app/models/concerns/hyrax/solr_document/characterization.rb,
app/renderers/hyrax/renderers/faceted_attribute_renderer.rb,
app/renderers/hyrax/renderers/license_attribute_renderer.rb,
app/search_builders/hyrax/dashboard/works_search_builder.rb,
app/search_builders/hyrax/expired_embargo_search_builder.rb,
app/search_builders/hyrax/single_use_link_search_builder.rb,
app/services/hyrax/characterization/file_set_description.rb,
app/services/hyrax/collections/collection_member_service.rb,
app/services/hyrax/custom_queries/find_by_property_value.rb,
app/services/hyrax/listeners/batch_notification_listener.rb,
app/services/hyrax/listeners/file_set_lifecycle_listener.rb,
app/services/hyrax/workflow/object_in_workflow_decorator.rb,
app/utils/hyrax/data_destroyers/featured_works_destroyer.rb,
app/utils/hyrax/test_data_seeders/collection_type_seeder.rb,
lib/hyrax/controlled_vocabularies/resource_label_caching.rb,
lib/hyrax/transactions/steps/check_for_default_admin_set.rb,
app/controllers/concerns/hyrax/leases_controller_behavior.rb,
app/indexers/hyrax/collection_with_basic_metadata_indexer.rb,
app/models/concerns/hyrax/ability/collection_type_ability.rb,
app/search_builders/hyrax/single_admin_set_search_builder.rb,
app/search_builders/hyrax/valkyrie_abstract_type_relation.rb,
app/services/hyrax/collections/permissions_create_service.rb,
app/services/hyrax/workflow/changes_required_notification.rb,
app/controllers/concerns/hyrax/breadcrumbs_for_collections.rb,
app/controllers/concerns/hyrax/collections/accepts_batches.rb,
app/controllers/hyrax/admin/analytics/analytics_controller.rb,
app/helpers/hyrax/citations_behaviors/publication_behavior.rb,
app/presenters/hyrax/select_collection_type_list_presenter.rb,
app/search_builders/hyrax/collection_member_search_builder.rb,
app/search_builders/hyrax/dashboard/managed_search_filters.rb,
app/search_builders/hyrax/deactivated_lease_search_builder.rb,
app/search_builders/hyrax/member_with_files_search_builder.rb,
app/search_builders/hyrax/parent_collection_search_builder.rb,
app/search_builders/hyrax/single_collection_search_builder.rb,
app/search_builders/hyrax/stats/work_status_search_builder.rb,
app/services/hyrax/collections/managed_collections_service.rb,
app/services/hyrax/custom_queries/find_collections_by_type.rb,
app/services/hyrax/workflow/workflow_permissions_generator.rb,
app/utils/hyrax/data_destroyers/collection_types_destroyer.rb,
app/controllers/hyrax/admin/permission_templates_controller.rb,
app/controllers/hyrax/dashboard/nest_collections_controller.rb,
app/models/concerns/hyrax/ability/flexible_metadata_ability.rb,
app/services/hyrax/workflow/invalid_state_removal_exception.rb,
app/controllers/concerns/hyrax/deny_access_override_behavior.rb,
app/controllers/concerns/hyrax/embargoes_controller_behavior.rb,
app/forms/hyrax/forms/admin/collection_type_participant_form.rb,
app/search_builders/hyrax/deactivated_embargo_search_builder.rb,
app/services/hyrax/custom_queries/find_many_by_alternate_ids.rb,
app/utils/hyrax/required_data_seeders/collection_type_seeder.rb,
app/controllers/hyrax/admin/analytics/work_reports_controller.rb,
app/controllers/hyrax/dashboard/collection_members_controller.rb,
app/models/concerns/hyrax/ability/permission_template_ability.rb,
app/services/hyrax/flexible_schema_validators/class_validator.rb,
app/services/hyrax/listeners/active_fedora_acl_index_listener.rb,
app/services/hyrax/resource_permissions_visibility_propagator.rb,
app/utils/hyrax/data_destroyers/collection_branding_destroyer.rb,
app/utils/hyrax/data_destroyers/repository_metadata_destroyer.rb,
app/utils/hyrax/required_data_seeders/flexible_profile_seeder.rb,
lib/hyrax/transactions/steps/set_uploaded_date_unless_present.rb,
app/controllers/concerns/hyrax/admin/users_controller_behavior.rb,
app/controllers/concerns/hyrax/breadcrumbs_for_works_analytics.rb,
app/controllers/concerns/hyrax/collections_controller_behavior.rb,
app/controllers/concerns/hyrax/singular_subresource_controller.rb,
app/helpers/hyrax/citations_behaviors/formatters/apa_formatter.rb,
app/helpers/hyrax/citations_behaviors/formatters/mla_formatter.rb,
app/renderers/hyrax/renderers/external_link_attribute_renderer.rb,
app/search_builders/hyrax/dashboard/collections_search_builder.rb,
app/services/hyrax/collections/nested_collection_query_service.rb,
app/services/hyrax/flexible_schema_validators/schema_validator.rb,
app/utils/hyrax/data_destroyers/permission_templates_destroyer.rb,
lib/hyrax/transactions/steps/apply_collection_type_permissions.rb,
app/actors/hyrax/actors/create_with_files_ordered_members_actor.rb,
app/search_builders/hyrax/admin_admin_set_member_search_builder.rb,
app/services/hyrax/collections/collection_member_search_service.rb,
app/services/hyrax/custom_queries/navigators/collection_members.rb,
lib/hyrax/transactions/steps/apply_workflow_on_admin_set_change.rb,
app/renderers/hyrax/renderers/redirects_label_attribute_renderer.rb,
app/services/hyrax/workflow/notification_configuration_parameter.rb,
lib/hyrax/transactions/steps/apply_permission_template_on_update.rb,
app/renderers/hyrax/renderers/rights_statement_attribute_renderer.rb,
app/services/hyrax/flexible_schema_validators/redirects_validator.rb,
app/services/hyrax/persist_directly_contained_output_file_service.rb,
app/helpers/hyrax/citations_behaviors/formatters/chicago_formatter.rb,
app/search_builders/hyrax/nested_collections_parent_search_builder.rb,
app/services/hyrax/custom_queries/navigators/child_works_navigator.rb,
app/services/hyrax/custom_queries/navigators/parent_work_navigator.rb,
app/controllers/concerns/hyrax/breadcrumbs_for_collection_analytics.rb,
app/controllers/hyrax/admin/analytics/collection_reports_controller.rb,
app/controllers/hyrax/admin/collection_type_participants_controller.rb,
app/controllers/hyrax/admin/permission_template_accesses_controller.rb,
app/helpers/hyrax/citations_behaviors/formatters/open_url_formatter.rb,
app/services/hyrax/collections/nested_collection_persistence_service.rb,
app/utils/hyrax/data_destroyers/default_admin_set_id_cache_destroyer.rb,
app/controllers/concerns/hyrax/valkyrie_downloads_controller_behavior.rb,
app/search_builders/hyrax/dashboard/nested_collections_search_builder.rb,
app/services/hyrax/custom_queries/navigators/child_filesets_navigator.rb,
app/services/hyrax/flexible_schema_validators/core_metadata_validator.rb,
app/services/hyrax/listeners/file_set_lifecycle_notification_listener.rb,
app/actors/hyrax/actors/create_with_remote_files_ordered_members_actor.rb,
app/services/hyrax/custom_queries/navigators/child_file_sets_navigator.rb,
app/controllers/concerns/hyrax/local_file_downloads_controller_behavior.rb,
app/services/hyrax/flexible_schema_validators/sort_properties_validator.rb,
app/controllers/concerns/hyrax/stream_file_downloads_controller_behavior.rb,
app/services/hyrax/custom_queries/navigators/child_collections_navigator.rb,
app/services/hyrax/flexible_schema_validators/existing_records_validator.rb,
app/services/hyrax/custom_queries/navigators/parent_collections_navigator.rb

Overview

this class overrides the Valkyrie::Storage::Disk::BucketStorage class so that file paths match

Defined Under Namespace

Modules: API, Ability, AbilityHelper, Action, Actors, Admin, Analytics, AnalyticsErrorHandling, AnnotatesContent, ApplicationCable, ArResource, Arkivo, AttributesHelper, AuthorityRenderingHelper, AuthorityService, BasedNearFieldBehavior, BasicMetadata, BatchEditsHelper, BlacklightOverride, Breadcrumbs, BreadcrumbsForCollectionAnalytics, BreadcrumbsForCollections, BreadcrumbsForWorks, BreadcrumbsForWorksAnalytics, Callbacks, Characterization, CharacterizationBehavior, ChartsHelper, CitationsBehavior, CitationsBehaviors, CollectionBehavior, CollectionTypes, Collections, CollectionsControllerBehavior, CollectionsHelper, ContactFormHelper, ContainedInWorksBehavior, ContentBlockHelper, ContentBlockHelperBehavior, ControlledVocabularies, ControlledVocabulary, Controller, CoreMetadata, CustomQueries, Dashboard, DashboardHelperBehavior, DataDestroyers, DenyAccessOverrideBehavior, DepositAgreementBehavior, DisplaysContent, DisplaysImage, DisplaysTranscripts, EmbargoHelper, Embargoable, EmbargoesControllerBehavior, EnsureMigratedBehavior, EnsureWellFormedAdminSetService, FacetsHelper, FileSetBehavior, FileSetFormHelper, FileSetHelper, FilterByType, FilterSuppressed, FilterSuppressedWithRoles, Fixity, Flexibility, FlexibleCatalogBehavior, FlexibleFormBehavior, FlexibleSchemaBehavior, FlexibleSchemaValidators, Forms, GroupBehavior, HasRendering, HasRepresentative, HealthChecks, HumanReadableType, HyraxHelperBehavior, Identifier, IiifHelper, InAdminSet, Indexers, IndexesBasicMetadata, IndexesLinkedMetadata, IndexesThumbnails, IndexesWorkflow, LeaseHelper, LeaseabilityBehavior, LeasesControllerBehavior, Listeners, LocalFileDownloadsControllerBehavior, LocationIndexer, Lockable, ManagesEmbargoes, MembersPermissionJobBehavior, MembershipHelper, MissingMethodBehavior, ModelProxy, My, Naming, NestedWorks, Noid, PermalinkHelper, PermalinkPath, PermissionBehavior, PermissionIndexer, PermissionJobBehavior, PermissionLevelsHelper, Permissions, PermissionsHelper, PresentsAttributes, ProxyDeposit, QueuedJobBehavior, RedirectPathNormalizer, RedirectToDisplayUrl, RedirectsFieldBehavior, RedirectsNormalization, RedirectsTabHelper, Renderers, RequiredDataSeeders, ResourceSync, ResourceTypesService, Riiif, RuboCop, SearchFilters, Serializers, SingleResult, SingularSubresourceController, SolrDocument, SolrDocumentBehavior, Specs, Statistics, Stats, Strategies, StreamFileDownloadsControllerBehavior, Suppressible, Test, TestDataSeeders, ThemedLayoutController, ThumbnailIndexer, TitleHelper, Transactions, TranscriptsBehavior, TrophyHelper, TwitterPresenter, User, UserUsageStats, ValkyrieDownloadsControllerBehavior, ValkyrieLazyMigration, VirusCheck, VisibilityIndexer, WithEmbargoesAndLeases, WithEvents, WorkBehavior, WorkFormHelper, Workflow, WorkflowIndexer, WorkflowsHelper, Works, WorksControllerBehavior, WorksHelper, Zotero Classes: AbstractMessageService, AbstractTypeRelation, AccessControl, AccessControlList, ActiveFedoraDummyModel, AdminAdminSetMemberSearchBuilder, AdminSetCreateService, AdminSetIndexer, AdminSetMemberService, AdminSetOptionsPresenter, AdminSetPresenter, AdminSetSearchBuilder, AdminSetSelectionPresenter, AdminSetService, AdminStatsPresenter, AdministrativeSet, AdministrativeSetIndexer, AdministrativeSetName, ApplicationJob, ArkivoApiGenerator, ArkivoConstraint, AssetsGenerator, AvatarUploader, AvatarValidator, Base, BasicMetadataIndexer, BatchCreateFailureService, BatchCreateOperation, BatchCreateSuccessService, BatchEditsController, BatchUploadsController, BootstrapBreadcrumbsBuilder, CachingIiifManifestBuilder, CatalogSearchBuilder, ChangeContentDepositorService, ChangeDepositorService, ChangeSet, ChartData, ChildTypes, CitationsController, ClamavGenerator, CleanConnection, CollapsableSectionPresenter, CollectionGenerator, CollectionIndexer, CollectionMemberSearchBuilder, CollectionMemberService, CollectionMembershipValidator, CollectionName, CollectionPresenter, CollectionResourceGenerator, CollectionSearchBuilder, CollectionThumbnailPathService, CollectionType, CollectionTypeParticipant, CollectionWithBasicMetadataIndexer, CollectionsController, CollectionsService, CompositePresenterFactory, ConfigGenerator, Configuration, ContactForm, ContactFormController, ContactMailer, ContentBlocksController, ContextualPath, ControlledVocabularyValidator, ControllerResource, CounterMetric, CurationConcern, DashboardController, DataMaintenance, DatabaseMigrator, DeactivatedEmbargoSearchBuilder, DeactivatedLeaseSearchBuilder, DeepIndexingService, DefaultAdministrativeSet, DefaultMiddlewareStack, DepositSearchBuilder, DepositorsController, DerivativeBucketedStorage, DerivativePath, DerivativeService, Download, DownloadsController, DropdownFacetFieldComponent, EditPermissionsService, Embargo, EmbargoManager, EmbargoPresenter, EmbargoSearchBuilder, EmbargoService, EmbargoesController, Engine, Event, EventStore, ExpiredEmbargoSearchBuilder, ExpiredLeaseSearchBuilder, ExposedModelsRelation, Feature, FeaturedWorkListsController, FeaturedWorksController, FileMetadata, FileSet, FileSetCsvService, FileSetDerivativesService, FileSetFileService, FileSetFixityCheckService, FileSetIndexer, FileSetPresenter, FileSetSearchBuilder, FileSetTypeService, FileSetVisibilityPropagator, FileSetsController, FileUsage, FindObjectsViaSolrService, FixityCheckFailureService, FixityChecksController, FixityStatusPresenter, FlexibleSchema, FlexibleSchemaValidatorService, FormBuilder, FormFactory, FormFields, FormMetadataService, GoogleScholarPresenter, GrantEditJob, GrantEditToMembersJob, GrantReadJob, GrantReadToMembersJob, GraphExporter, Group, HasOneTitleValidator, HealthCheckGenerator, HomepageController, HomepagePresenter, HomepageSearchBuilder, HyraxError, IiifAuthorizationService, IiifManifestPresenter, IiifViewerGenerator, ImportUrlFailureService, Indexer, InspectWorkPresenter, Install, Institution, Lease, LeaseManager, LeasePresenter, LeaseSearchBuilder, LeaseService, LeasesController, LicenseService, ListSourceExporter, ListenersGenerator, LocalFileService, LocationService, LockManager, M3ProfileEditor, M3SchemaLoader, ManifestBuilderService, ManifestHelper, MemberPresenterFactory, MemberWithFilesSearchBuilder, MenuPresenter, MessengerService, Microdata, MissingWorkflowError, ModelDecorator, ModelIcon, ModelMismatchError, ModelRegistry, ModelsGenerator, MultipleMembershipChecker, MyController, Name, NestedCollectionsParentSearchBuilder, NotificationsChannel, NotificationsController, ObjectNotFoundError, Operation, OperationsController, OrcidValidator, PageTitleDecorator, PagesController, Pageview, ParentCollectionSearchBuilder, PcdmCollection, PcdmCollectionIndexer, PcdmMemberPresenterFactory, Permission, PermissionBadge, PermissionManager, PermissionTemplate, PermissionTemplateAccess, PermissionTemplateApplicator, PermissionsController, PersistDerivatives, PersistDirectlyContainedOutputFileService, PresenterFactory, PresenterRenderer, PropagateChangeDepositorJob, Publisher, QaSelectService, QueuedDeleteJob, QueuedIndexingJob, QuickClassificationQuery, Redirect, RedirectPath, RedirectValidator, RedirectsController, RedirectsLookup, RedisEventStore, RepositoryFixityCheckService, RequiredDataSeeder, Resource, ResourceName, ResourcePermissionsVisibilityPropagator, ResourceStatus, ResourceSyncController, ResourceVisibilityPropagator, RestrictionService, RevokeEditFromMembersJob, RevokeEditJob, RightsStatementService, RiiifGenerator, RoleRegistry, SampleDataGenerator, Schema, SchemaLoader, SearchBuilder, SearchService, SearchState, SelectCollectionTypeListPresenter, SelectCollectionTypePresenter, SelectTypeListPresenter, SelectTypePresenter, SimpleSchemaLoader, SingleAdminSetSearchBuilder, SingleCollectionSearchBuilder, SingleMembershipError, SingleUseError, SingleUseLinkPresenter, SingleUseLinkSearchBuilder, SingleUseLinksController, SingleUseLinksViewerController, SolrQueryBuilderService, SolrQueryService, SolrService, StaticController, Statistic, StatsController, StatsUsagePresenter, TestDataSeeder, ThumbnailPathService, TimeService, TolerantSelectService, TranscriptsController, TransfersController, TransfersPresenter, TrophiesController, TrophyPresenter, UploadedFile, UploadedFileUploader, UploadsController, UserProfilePresenter, UserStatImporter, UsersController, ValkyrieAbstractTypeRelation, ValkyrieCanCanAdapter, ValkyrieCollectionIndexer, ValkyrieFileSetIndexer, ValkyrieGlobalIdProxy, ValkyrieIndexer, ValkyriePersistDerivatives, ValkyrieSimplePathGenerator, ValkyrieUpload, ValkyrieWorkIndexer, ValkyrieWorkRelation, VersionCommitter, VersionListPresenter, VersionPresenter, VersioningService, VirusCheckerService, VirusScanner, VisibilityIntention, VisibilityIntentionApplicator, VisibilityMap, VisibilityPropagator, VisibilityReader, VisibilityWriter, Work, WorkFormService, WorkGenerator, WorkIndexer, WorkQueryService, WorkRelation, WorkResourceGenerator, WorkResourceQueryService, WorkSearchBuilder, WorkShowPresenter, WorkThumbnailPathService, WorkUploadsHandler, WorkUsage, WorkflowActionInfo, WorkflowActionsController, WorkflowAuthorizationException, WorkflowPresenter, WorkingDirectory, WorksSearchBuilder

Constant Summary collapse

VERSION =
'5.3.0'

Class Method Summary collapse

Class Method Details

.AccessControlList(obj) ⇒ Hyrax::AccessControlList

Cast an object to its AccessControlList

Parameters:

  • object to try to cast

Returns:

API:

  • public



12
13
14
15
16
17
18
19
# File 'app/services/hyrax/access_control_list.rb', line 12

def self.AccessControlList(obj)
  case obj
  when AccessControlList
    obj
  else
    obj.try(:permission_manager)&.acl || AccessControlList.new(resource: obj)
  end
end

.ChangeSet(resource_class) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Build a changeset class for the given resource class. The ChangeSet will have fields to match the resource class given.

To define a custom changeset with validations, use naming convention with "ChangeSet" appended to the end of the resource class name. (e.g. for BookResource, name the change set BookResourceChangeSet)

Examples:

Hyrax::ChangeSet(Monograph)

API:

  • private



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
# File 'app/models/hyrax/change_set.rb', line 15

def self.ChangeSet(resource_class)
  klass = (resource_class.name + "ChangeSet").safe_constantize || Hyrax::ChangeSet
  Class.new(klass) do
    (resource_class.fields - resource_class.reserved_attributes).each do |field|
      property field, default: nil
    end

    ##
    # @return [String]
    define_singleton_method :inspect do
      return "Hyrax::ChangeSet(#{resource_class})" if name.blank?
      super
    end
  end
end

.config {|Hyrax::Configuration| ... } ⇒ Hyrax::Configuration

Exposes the Hyrax configuration

Yields:

Returns:

See Also:

API:

  • public



81
82
83
84
85
86
87
# File 'lib/hyrax.rb', line 81

def self.config(&block)
  @config ||= Hyrax::Configuration.new

  yield @config if block

  @config
end

.custom_queriesObject

The custom queries common to Hyrax



149
150
151
# File 'lib/hyrax.rb', line 149

def self.custom_queries
  query_service.custom_queries
end

.deprecationObject

Alias for backwards compatibility



28
29
30
# File 'lib/hyrax/deprecation.rb', line 28

def self.deprecation
  deprecator
end

.deprecator(major_version = nil) ⇒ Object

Provides version-specific deprecators for Hyrax

Examples:

Standard usage for next major version

Hyrax.deprecator.warn("This will be removed in Hyrax 6.0")

Specific version targeting

Hyrax.deprecator(7).warn("This will be removed in Hyrax 7.0")

Marking technical debt

Hyrax.deprecator(4).warn("This should have been removed in Hyrax 4.0")


14
15
16
17
18
19
20
21
22
23
24
25
# File 'lib/hyrax/deprecation.rb', line 14

def self.deprecator(major_version = nil)
  @deprecators ||= {}

  # Default to next major version if not specified
  major_version ||= 6 # Update this when 6.0 is released

  @deprecators[major_version] ||= begin
    dep = ActiveSupport::Deprecation.new("#{major_version}.0", "Hyrax")
    dep.behavior = Rails.application.config.active_support.deprecation
    dep
  end
end

.FileMetadata(file) ⇒ Hyrax::FileMetadata

Casts a resource to an associated FileMetadata

Parameters:

Returns:

Raises:



11
12
13
14
15
16
17
18
19
20
21
22
# File 'app/models/hyrax/file_metadata.rb', line 11

def self.FileMetadata(file)
  raise(ArgumentError, "Expected a Valkyrie::StorageAdapter::File; got #{file.class}: #{file}") if
    file.is_a?(Valkyrie::Resource)

  Hyrax.custom_queries.(id: file.id)
rescue Hyrax::ObjectNotFoundError, Ldp::BadRequest, Valkyrie::Persistence::ObjectNotFoundError
  Hyrax.logger.debug('Could not find an existing metadata node for file ' \
                     "with id #{file.id}. Initializing a new one")

  FileMetadata.new(file_identifier: file.id,
                   original_filename: File.basename(file.disk_path))
end

.FormFields(schema_name, **options) ⇒ Object

Parameters:

Since:

  • 3.0.0

API:

  • public



10
11
12
# File 'lib/hyrax/form_fields.rb', line 10

def self.FormFields(schema_name, **options)
  Hyrax::FormFields.new(schema_name, **options)
end

.GlobalID(input) ⇒ GlobalID



62
63
64
65
66
67
68
69
70
71
# File 'lib/hyrax.rb', line 62

def self.GlobalID(input) # rubocop:disable Naming/MethodName
  case input
  when Valkyrie::Resource
    return input.to_global_id if input.respond_to?(:to_global_id)

    ValkyrieGlobalIdProxy.new(resource: input).to_global_id
  else
    input.to_global_id if input.respond_to?(:to_global_id)
  end
end

.index_adapterValkyrie::IndexingAdapter

Returns:



101
102
103
# File 'lib/hyrax.rb', line 101

def self.index_adapter
  config.index_adapter
end

.Indexer(schema_name, index_loader: SimpleSchemaLoader.new) ⇒ Module

Build an indexer module from a schema. Generates custom indexer behavior from rules provided by index_loader.

Examples:

building a module as a mixin


class MyIndexer < Hyrax::Indexers::ResourceIndexer
  include Hyrax::Indexer(:core_metadata)
end

building a module as a mixin with flexible metadata


class MyIndexer < Hyrax::Indexers::ResourceIndexer
  include Hyrax::Indexer(:MyResource, index_loader: M3SchemaLoader.new)
end

Parameters:

  • (defaults to: SimpleSchemaLoader.new)

Returns:

Since:

  • 3.0.0

API:

  • public



28
29
30
# File 'lib/hyrax/indexer.rb', line 28

def self.Indexer(schema_name, index_loader: SimpleSchemaLoader.new)
  Indexer.new(schema_name: schema_name, index_loader: index_loader)
end

.loggerLogger

Returns:



91
92
93
# File 'lib/hyrax.rb', line 91

def self.logger
  config.logger
end

.metadata_adapterObject

Note:

always use this method to retrieve the metadata adapter when data interoperability with Hyrax is required

The Valkyrie metadata adapter used for PCDM models throughout Hyrax



125
126
127
# File 'lib/hyrax.rb', line 125

def self.
  Valkyrie.config.
end

.persisterObject

Note:

always use this method to retrieve the persister when data interoperability with Hyrax is required

The Valkyrie persister used for PCDM models throughout Hyrax



116
117
118
# File 'lib/hyrax.rb', line 116

def self.persister
  .persister
end

.primary_work_typeObject



95
96
97
# File 'lib/hyrax.rb', line 95

def self.primary_work_type
  config.curation_concerns.first
end

.publisherDry::Events::Publisher

Returns:



107
108
109
# File 'lib/hyrax.rb', line 107

def self.publisher
  config.publisher
end

.query_serviceObject

Note:

always use this method to retrieve the query service when data interoperability with Hyrax is required

The Valkyrie query service used for PCDM files throughout Hyrax



143
144
145
# File 'lib/hyrax.rb', line 143

def self.query_service
  .query_service
end

.Schema(schema_name, **options) ⇒ Module

Note:

Valkyrie::Resource and Resource classes are not required to use this interface, and may define custom attributes using the base Valkyrie::Resource.attribute interface. This mechanism is provided to allow schemas to be defined in a unified way that don't require programmer intervention ("configurable schemas"). While the default schema loader derives schemas from configuration files, alternate implementations could provide schema definitions pulled from repository storage, an external schema service, etc...

Builds a schema module for a Valkyrie::Resource. The schema itself is resolved by a schema loader instance, which must implement SimpleSchemaLoader#attributes_for, with a hash from attribute names to Dry::Type types.

For the default schema loader, configuration is loaded from config/metadata/{name}.yaml. A custom schema loader can be provided as :schema_loader to resolve the schema in other ways.

Examples:

class Monograph < Valkyrie::Resource
  include Hyrax::Schema(:book)
end

with a custom schema loader

class Monograph < Valkyrie::Resource
  include Hyrax::Schema(:book, schema_loader: MySchemaLoader.new)
end

Parameters:

Returns:

  • a module that, when included, applies a schema to a Valkyire::Resource

Since:

  • 3.0.0

API:

  • public



43
44
45
# File 'lib/hyrax/schema.rb', line 43

def self.Schema(schema_name, **options)
  Hyrax::Schema.new(schema_name, **options)
end

.schema_for(klass:, admin_set_id: nil) ⇒ Dry::Types::Schema, Array

Returns the schema for a resource class, optionally scoped by admin set contexts.

When admin_set_id is present and flexible schema is enabled, the admin set's contexts are used so flexible resources get a context-aware schema. If the admin set is not found, falls back to the base schema without raising.

Parameters:

  • a Valkyrie resource class (e.g. Hyrax::Work)

  • (defaults to: nil)

    optional admin set id to resolve contexts from

Returns:

  • the schema (keys/types or enumerable of keys)



163
164
165
166
167
168
169
170
171
172
# File 'lib/hyrax.rb', line 163

def self.schema_for(klass:, admin_set_id: nil)
  contexts = if admin_set_id.blank? || !config.flexible?
               []
             else
               schema_contexts_for(admin_set_id)
             end
  resolve_schema(klass, contexts)
rescue Valkyrie::Persistence::ObjectNotFoundError
  fallback_schema(klass)
end

.storage_adapterObject

Note:

always use this method to retrieve the storage adapter when handling files that will be used by Hyrax

The Valkyrie storage_adapter used for PCDM files throughout Hyrax



134
135
136
# File 'lib/hyrax.rb', line 134

def self.storage_adapter
  Valkyrie.config.storage_adapter
end