Class: Hyrax::AdministrativeSet
- Inherits:
-
Resource
- Object
- Resource
- Hyrax::AdministrativeSet
- Defined in:
- app/models/hyrax/administrative_set.rb
Overview
Valkyrie model for Admin Set domain objects.
Relationships
Administrative Set and Work
-
Defined: The relationship is defined by the inverse relationship stored in the work's
:admin_set_idattribute. -
Tested: The work tests the relationship.
-
Administrative Set to Work: (1..m) An admin set can have many works.
-
Work to Administrative Set: (1..1) A work must be in one and only one admin set.
- See Hyrax::Work for code to get and set the admin set for the work.
Class Method Summary collapse
-
._hyrax_default_name_class ⇒ Class
private
An ActiveModel::Name compatible class.
-
.pcdm_collection? ⇒ Boolean
True.
Instance Method Summary collapse
Class Method Details
._hyrax_default_name_class ⇒ Class
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns an ActiveModel::Name compatible class.
49 50 51 |
# File 'app/models/hyrax/administrative_set.rb', line 49 def self._hyrax_default_name_class Hyrax::AdministrativeSetName end |
.pcdm_collection? ⇒ Boolean
Returns true.
36 37 38 |
# File 'app/models/hyrax/administrative_set.rb', line 36 def self.pcdm_collection? true end |
Instance Method Details
#collection_type_gid ⇒ Object
40 41 42 43 |
# File 'app/models/hyrax/administrative_set.rb', line 40 def collection_type_gid # allow AdministrativeSet to behave more like a regular PcdmCollection Hyrax::CollectionType.find_or_create_admin_set_type.to_global_id end |