Module: Hyrax::FlexibleCatalogBehavior
- Extended by:
- ActiveSupport::Concern
- Defined in:
- app/controllers/concerns/hyrax/flexible_catalog_behavior.rb
Instance Method Summary collapse
- #initialize ⇒ Object
-
#render_optionally? ⇒ Boolean
Hook to allow optional rendering at the app level.
Instance Method Details
#initialize ⇒ Object
196 197 198 199 |
# File 'app/controllers/concerns/hyrax/flexible_catalog_behavior.rb', line 196 def initialize self.class.load_flexible_schema super end |
#render_optionally? ⇒ Boolean
Hook to allow optional rendering at the app level
202 203 204 |
# File 'app/controllers/concerns/hyrax/flexible_catalog_behavior.rb', line 202 def render_optionally? true end |