Class: Hyrax::Install

Inherits:
Rails::Generators::Base
  • Object
show all
Defined in:
lib/generators/hyrax/install_generator.rb

Instance Method Summary collapse

Instance Method Details

#blacklight_dynamic_sitemapObject



233
234
235
# File 'lib/generators/hyrax/install_generator.rb', line 233

def blacklight_dynamic_sitemap
  copy_file 'app/views/blacklight_dynamic_sitemap/sitemap/show.xml.builder', 'app/views/blacklight_dynamic_sitemap/sitemap/show.xml.builder'
end

#catalog_controllerObject



148
149
150
# File 'lib/generators/hyrax/install_generator.rb', line 148

def catalog_controller
  copy_file "catalog_controller.rb", "app/controllers/catalog_controller.rb"
end

#configure_usage_statsObject



117
118
119
# File 'lib/generators/hyrax/install_generator.rb', line 117

def configure_usage_stats
  copy_file 'config/analytics.yml', 'config/analytics.yml'
end

#copy_helperObject



152
153
154
# File 'lib/generators/hyrax/install_generator.rb', line 152

def copy_helper
  copy_file 'hyrax_helper.rb', 'app/helpers/hyrax_helper.rb'
end

#create_workflowObject



104
105
106
107
# File 'lib/generators/hyrax/install_generator.rb', line 104

def create_workflow
  template('workflow.json.erb', "config/workflows/default_workflow.json")
  template('mediated_deposit_workflow.json.erb', "config/workflows/mediated_deposit_workflow.json")
end

#datatablesObject



183
184
185
186
187
188
189
190
191
192
193
# File 'lib/generators/hyrax/install_generator.rb', line 183

def datatables
  javascript_manifest = 'app/assets/javascripts/application.js'
  insert_into_file javascript_manifest, after: /jquery.?\n/ do
    "//= require jquery.dataTables\n" \
    "//= require dataTables.bootstrap4\n"
  end

  insert_into_file 'app/assets/stylesheets/application.css', before: ' *= require_self' do
    " *= require dataTables.bootstrap4\n"
  end
end

#dotenvObject



226
227
228
229
230
231
# File 'lib/generators/hyrax/install_generator.rb', line 226

def dotenv
  copy_file '.env'
  gem_group :development, :test do
    gem 'dotenv-rails', '~> 2.8'
  end
end

#health_checkObject



199
200
201
# File 'lib/generators/hyrax/install_generator.rb', line 199

def health_check
  generate 'hyrax:health_check' unless options[:'skip-health-check']
end

#inject_abilityObject

we're going to inject this into the local app, so that it's easy to disable.



122
123
124
125
126
127
# File 'lib/generators/hyrax/install_generator.rb', line 122

def inject_ability
  inject_into_file 'app/models/ability.rb', after: /Hydra::Ability\s*\n/ do
    "  include Hyrax::Ability\n"\
    "  self.ability_logic += [:everyone_can_create_curation_concerns]\n\n"
  end
end

#inject_hyrax_application_controller_behaviorObject

Add behaviors to the application controller



136
137
138
139
140
141
142
143
144
145
146
# File 'lib/generators/hyrax/install_generator.rb', line 136

def inject_hyrax_application_controller_behavior
  file_path = "app/controllers/application_controller.rb"
  if File.exist?(file_path)
    insert_into_file file_path, after: /Hydra::Controller::ControllerBehavior\s*\n/ do
      "\n  # Adds Hyrax behaviors into the application controller" \
      "\n  include Hyrax::Controller\n"
    end
  else
    puts "     \e[31mFailure\e[0m  Could not find #{file_path}.  To add Hyrax behaviors to your Controllers, you must include the Hyrax::Controller module in the Controller class definition."
  end
end

#inject_listenersObject

add listener code to provide developers a hint that listening to events is a good development pattern



131
132
133
# File 'lib/generators/hyrax/install_generator.rb', line 131

def inject_listeners
  generate "hyrax:listeners"
end

#inject_required_seedsObject



160
161
162
163
164
# File 'lib/generators/hyrax/install_generator.rb', line 160

def inject_required_seeds
  insert_into_file 'db/seeds.rb' do
    'Hyrax::RequiredDataSeeder.new.generate_seed_data'
  end
end

#inject_routesObject

The engine routes have to come after the devise routes so that /users/sign_in will work



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/generators/hyrax/install_generator.rb', line 64

def inject_routes # rubocop:disable Metrics/MethodLength
  # Remove root route that was added by blacklight generator
  gsub_file 'config/routes.rb', /root (:to =>|to:) "catalog#index"/, ''

  inject_into_file 'config/routes.rb', after: /devise_for :users\s*\n/ do
    "  mount Qa::Engine => '/authorities'\n"\
    "  mount BlacklightDynamicSitemap::Engine => '/'\n"\
    "  mount Hyrax::Engine, at: '/'\n"\
    "  resources :welcome, only: 'index'\n"\
    "  root 'hyrax/homepage#index'\n"\
    "  curation_concerns_basic_routes\n"\
  end

  # Catch-all redirect resolver. Must be the last route in the host
  # application so that every other route — engine mounts, host-specific
  # routes, curation concerns — gets first crack at matching the request.
  # Gated by Hyrax.config.redirects_active? at request time so the route is
  # transparent when the redirects feature is off.
  # See documentation/redirects.md.
  inject_into_file 'config/routes.rb', before: /^end\s*\Z/ do
    "\n  # Catch-all redirect resolver — must be last. See documentation/redirects.md.\n"\
    "  get '*alias_path', to: 'hyrax/redirects#show',\n"\
    "                     constraints: ->(_req) { Hyrax.config.redirects_active? },\n"\
    "                     format: false\n"
  end
end

#inject_solr_document_behaviorObject

Add behaviors to the SolrDocument model



92
93
94
95
96
97
98
99
100
101
102
# File 'lib/generators/hyrax/install_generator.rb', line 92

def inject_solr_document_behavior
  file_path = 'app/models/solr_document.rb'
  if File.exist?(file_path)
    inject_into_file file_path, after: /include Blacklight::Solr::Document.*$/ do
      "\n  # Adds Hyrax behaviors to the SolrDocument.\n" \
        "  include Hyrax::SolrDocumentBehavior\n"
    end
  else
    puts "     \e[31mFailure\e[0m  Hyrax requires a SolrDocument object. This generators assumes that the model is defined in the file #{file_path}, which does not exist."
  end
end

#insert_application_configObject



207
208
209
210
211
# File 'lib/generators/hyrax/install_generator.rb', line 207

def insert_application_config
  insert_into_file 'config/application.rb', after: /config\.load_defaults [0-9.]+$/ do
    "\n    config.active_job.queue_adapter = ENV.fetch('HYRAX_ACTIVE_JOB_QUEUE') { 'async' }.to_sym\n"
  end
end

#insert_builderObject



55
56
57
58
59
60
61
# File 'lib/generators/hyrax/install_generator.rb', line 55

def insert_builder
  insert_into_file 'app/models/search_builder.rb', after: /include Blacklight::Solr::SearchBuilderBehavior/ do
    "\n  # Add a filter query to restrict the search to documents the current user has access to\n"\
    "  include Hydra::AccessControlsEnforcement\n"\
    "  include Hyrax::SearchFilters\n"
  end
end

#install_assetsObject



166
167
168
# File 'lib/generators/hyrax/install_generator.rb', line 166

def install_assets
  generate "hyrax:assets"
end


176
177
178
179
180
181
# File 'lib/generators/hyrax/install_generator.rb', line 176

def install_blacklight_gallery
  generate "blacklight_gallery:install"
  # This was pulling in an extra copy of bootstrap, so we added the needed
  # includes to hyrax.scss
  remove_file 'app/assets/stylesheets/blacklight_gallery.css.scss'
end

#install_configObject



109
110
111
# File 'lib/generators/hyrax/install_generator.rb', line 109

def install_config
  generate "hyrax:config"
end

#install_mailboxerObject



113
114
115
# File 'lib/generators/hyrax/install_generator.rb', line 113

def install_mailboxer
  generate "mailboxer:install"
end

#landoObject



218
219
220
# File 'lib/generators/hyrax/install_generator.rb', line 218

def lando
  copy_file '.lando.yml'
end

#noid_rails_database_minter_initializeObject



195
196
197
# File 'lib/generators/hyrax/install_generator.rb', line 195

def noid_rails_database_minter_initialize
  generate 'noid:rails:install'
end

#qa_tablesObject



156
157
158
# File 'lib/generators/hyrax/install_generator.rb', line 156

def qa_tables
  generate 'qa:local:tables'
end

#remove_robotsObject



222
223
224
# File 'lib/generators/hyrax/install_generator.rb', line 222

def remove_robots
  remove_file 'public/robots.txt'
end

#replace_blacklight_layoutObject



50
51
52
53
# File 'lib/generators/hyrax/install_generator.rb', line 50

def replace_blacklight_layout
  gsub_file 'app/controllers/application_controller.rb', /layout :determine_layout.+$/,
            "include Hyrax::ThemedLayoutController\n  with_themed_layout '1_column'\n"
end

#riiif_image_serverObject



203
204
205
# File 'lib/generators/hyrax/install_generator.rb', line 203

def riiif_image_server
  generate 'hyrax:riiif' unless options[:'skip-riiif']
end

#run_required_generatorsObject



41
42
43
44
45
46
47
48
# File 'lib/generators/hyrax/install_generator.rb', line 41

def run_required_generators
  say_status('info', '[Hyrax] GENERATING BLACKLIGHT', :blue)
  generate 'blacklight:install --devise'
  say_status('info', '[Hyrax] GENERATING HYDRA-HEAD', :blue)
  generate 'hydra:head -f'
  generate "hyrax:models#{options[:force] ? ' -f' : ''}"
  generate 'browse_everything:config'
end

#universalviewer_filesObject



213
214
215
216
# File 'lib/generators/hyrax/install_generator.rb', line 213

def universalviewer_files
  rake('hyrax:universal_viewer:install')
  rake('yarn:install')
end

#use_browser_validationsObject



170
171
172
173
174
# File 'lib/generators/hyrax/install_generator.rb', line 170

def use_browser_validations
  gsub_file 'config/initializers/simple_form.rb',
            /browser_validations = false/,
            'browser_validations = true'
end