Class: Hyrax::My::WorksSearchBuilder
- Inherits:
-
My::SearchBuilder
- Object
- My::SearchBuilder
- Hyrax::My::WorksSearchBuilder
- Includes:
- FilterByType
- Defined in:
- app/search_builders/hyrax/my/works_search_builder.rb
Overview
Added to allow for the Hyrax::My::WorksController to show only things I have deposited If the work went through mediated deposit, I may no longer have edit access to it.
Instance Method Summary collapse
Methods included from FilterByType
Instance Method Details
#only_works? ⇒ Boolean
14 15 16 |
# File 'app/search_builders/hyrax/my/works_search_builder.rb', line 14 def only_works? true end |