Class: Hyrax::Permission
- Inherits:
-
Valkyrie::Resource
- Object
- Valkyrie::Resource
- Hyrax::Permission
- Defined in:
- app/models/hyrax/permission.rb
Overview
Valkyrie native permissions (access policies) for Hyrax
Permissions are persisted independently from Hyrax::Resources (works,
collections, file sets, etc...) since their scope is different. Access policies
may be application-specific and tend to update more frequently than resource
metadata. This approach also allows policies to be persisted using a
different database or adapter than is used for curatorial objects.