Class: Hyrax::Transactions::Container
- Inherits:
-
Object
- Object
- Hyrax::Transactions::Container
- Extended by:
- Dry::Container::Mixin
- Defined in:
- lib/hyrax/transactions/container.rb
Overview
Provides a container for transaction steps related to creating, updating, and destroying PCDM Objects in Hyrax.
In advanced use, the container could provide runtime dependency injection
for particular step code. For the basic case, users can consider it as
providing namespacing and resolution for steps (as used in
Hyrax::Transaction::WorkCreate; e.g.
step :save, with: 'work_resource.save').