Class: Hyrax::WorkShowPresenter

Inherits:
Object
  • Object
show all
Includes:
MissingMethodBehavior, ModelProxy, PresentsAttributes
Defined in:
app/presenters/hyrax/work_show_presenter.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from PresentsAttributes

#attribute_to_html, #display_microdata?, #microdata_type_to_html, #permission_badge, #permission_badge_class

Methods included from ModelProxy

#persisted?, #to_model

Constructor Details

#initialize(solr_document, current_ability, request = nil) ⇒ WorkShowPresenter

Returns a new instance of WorkShowPresenter.

Parameters:

  • solr_document (SolrDocument)
  • current_ability (Ability)
  • request (ActionDispatch::Request) (defaults to: nil)

    the http request context. Used so the GraphExporter knows what URLs to draw.



24
25
26
27
28
29
# File 'app/presenters/hyrax/work_show_presenter.rb', line 24

def initialize(solr_document, current_ability, request = nil)
  @solr_document = Hyrax::SolrDocument::OrderedMembers.decorate(solr_document)
  @current_ability = current_ability
  @request = request
  define_dynamic_methods if @solr_document.flexible?
end

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Hyrax::MissingMethodBehavior

Instance Attribute Details

#current_abilityObject

Returns the value of attribute current_ability.



12
13
14
# File 'app/presenters/hyrax/work_show_presenter.rb', line 12

def current_ability
  @current_ability
end

#member_presenter_factory=(value) ⇒ Object

Sets the attribute member_presenter_factory

Parameters:

  • value

    the value to set the attribute member_presenter_factory to.



11
12
13
# File 'app/presenters/hyrax/work_show_presenter.rb', line 11

def member_presenter_factory=(value)
  @member_presenter_factory = value
end

#requestObject

Returns the value of attribute request.



12
13
14
# File 'app/presenters/hyrax/work_show_presenter.rb', line 12

def request
  @request
end

#solr_documentObject

Returns the value of attribute solr_document.



12
13
14
# File 'app/presenters/hyrax/work_show_presenter.rb', line 12

def solr_document
  @solr_document
end

Instance Method Details

#date_modifiedObject



138
139
140
# File 'app/presenters/hyrax/work_show_presenter.rb', line 138

def date_modified
  solr_document.date_modified.try(:to_formatted_s, :standard)
end

#date_uploadedObject



142
143
144
# File 'app/presenters/hyrax/work_show_presenter.rb', line 142

def date_uploaded
  solr_document.date_uploaded.try(:to_formatted_s, :standard)
end

#define_dynamic_methodsObject

rubocop:disable Metrics/CyclomaticComplexity, Metrics/MethodLength



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'app/presenters/hyrax/work_show_presenter.rb', line 31

def define_dynamic_methods # rubocop:disable Metrics/CyclomaticComplexity, Metrics/MethodLength
  Hyrax::FlexibleSchema.default_properties.each do |prop|
    method_name = prop.to_s
    property_details = Hyrax::FlexibleSchema.current_version["properties"][method_name]
    next unless property_details

    index_keys = property_details["indexing"]
    next unless index_keys

    multi_value = property_details['multiple'] || (property_details['data_type'] == 'array')

    next if self.class.method_defined?(method_name) && solr_document.respond_to?(method_name)
    # Define the method on the SolrDocument class
    Hyrax::SolrDocument::OrderedMembers.send(:define_method, method_name) do |*_args|
      index_keys.each do |index_key|
        value = self[index_key]
        return (multi_value ? Array.wrap(value) : value) if value.present?
      end
      multi_value ? [] : ""
    end

    # Define the method on the Presenter class
    self.class.send(:define_method, method_name) do |*args|
      @solr_document.send(method_name, *args)
    end
  end
end

#display_feature_link?Boolean

Returns:

  • (Boolean)


193
194
195
# File 'app/presenters/hyrax/work_show_presenter.rb', line 193

def display_feature_link?
  work_featurable? && FeaturedWork.can_create_another? && !featured?
end

#display_unfeature_link?Boolean

Returns:

  • (Boolean)


197
198
199
# File 'app/presenters/hyrax/work_show_presenter.rb', line 197

def display_unfeature_link?
  work_featurable? && featured?
end

#download_urlString

Returns a download URL, if work has representative media, or a blank string.

Returns:

  • (String)

    a download URL, if work has representative media, or a blank string



80
81
82
83
# File 'app/presenters/hyrax/work_show_presenter.rb', line 80

def download_url
  return '' if representative_presenter.nil?
  Hyrax::Engine.routes.url_helpers.download_url(representative_presenter, host: request.host)
end

#editor?Boolean

Deprecated.

use ::Ability.can?(:edit, presenter). Hyrax views calling presenter #editor methods will continue to call them until Hyrax 4.0.0. The deprecation time horizon for the presenter methods themselves is 5.0.0.

Returns:

  • (Boolean)


167
168
169
# File 'app/presenters/hyrax/work_show_presenter.rb', line 167

def editor?
  current_ability.can?(:edit, self)
end

#export_as_jsonldObject



154
155
156
# File 'app/presenters/hyrax/work_show_presenter.rb', line 154

def export_as_jsonld
  graph.dump(:jsonld, standard_prefixes: true)
end

#export_as_ntObject



150
151
152
# File 'app/presenters/hyrax/work_show_presenter.rb', line 150

def export_as_nt
  graph.dump(:ntriples)
end

#export_as_ttlObject



158
159
160
# File 'app/presenters/hyrax/work_show_presenter.rb', line 158

def export_as_ttl
  graph.dump(:ttl)
end

#grouped_presenters(filtered_by: nil, except: nil) ⇒ Array

Returns presenters grouped by model name, used to show the parents of this object.

Returns:

  • (Array)

    presenters grouped by model name, used to show the parents of this object



180
181
182
183
184
185
186
187
# File 'app/presenters/hyrax/work_show_presenter.rb', line 180

def grouped_presenters(filtered_by: nil, except: nil)
  # TODO: we probably need to retain collection_presenters (as parent_presenters)
  #       and join this with member_of_collection_presenters
  grouped = member_of_collection_presenters.group_by(&:model_name).transform_keys(&:human)
  grouped.select! { |obj| obj.casecmp(filtered_by).zero? } unless filtered_by.nil?
  grouped.reject! { |obj| except.map(&:downcase).include? obj.downcase } unless except.nil?
  grouped
end

#iiif_viewerSymbol

Returns the name of the IIIF viewer partial to render.

Examples:

A work presenter with a custom iiif viewer

module Hyrax
  class GenericWorkPresenter < Hyrax::WorkShowPresenter
    def iiif_viewer
      :my_iiif_viewer
    end
  end
end

Custom iiif viewer partial at app/views/hyrax/base/iiif_viewers/_my_iiif_viewer.html.erb
<h3>My IIIF Viewer!</h3>
<a href=<%= main_app.polymorphic_url([main_app, :manifest, presenter], { locale: nil }) %>>Manifest</a>

Returns:

  • (Symbol)

    the name of the IIIF viewer partial to render



108
109
110
111
112
113
114
# File 'app/presenters/hyrax/work_show_presenter.rb', line 108

def iiif_viewer
  if representative_presenter.present? && av_viewable?
    Hyrax.config.iiif_av_viewer
  else
    :universal_viewer
  end
end

#iiif_viewer?Boolean Also known as: universal_viewer?

Returns render a IIIF viewer.

Returns:

  • (Boolean)

    render a IIIF viewer



86
87
88
89
90
# File 'app/presenters/hyrax/work_show_presenter.rb', line 86

def iiif_viewer?
  representative_id.present? &&
    representative_presenter.present? &&
    (av_viewable? || image_viewable? || pdf_viewable?)
end

#inspect_workObject



75
76
77
# File 'app/presenters/hyrax/work_show_presenter.rb', line 75

def inspect_work
  @inspect_workflow ||= InspectWorkPresenter.new(solr_document, current_ability)
end


146
147
148
# File 'app/presenters/hyrax/work_show_presenter.rb', line 146

def link_name
  current_ability.can?(:read, id) ? to_s : 'Private'
end

#list_of_item_ids_to_displayArray

Returns list to display with Kaminari pagination.

Returns:

  • (Array)

    list to display with Kaminari pagination



212
213
214
# File 'app/presenters/hyrax/work_show_presenter.rb', line 212

def list_of_item_ids_to_display
  paginated_item_list(page_array: authorized_item_ids)
end

#manifest_metadataArray

IIIF metadata for inclusion in the manifest Called by the iiif_manifest gem to add metadata

Returns:

  • (Array)

    array of metadata hashes



239
240
241
242
243
244
245
246
# File 'app/presenters/hyrax/work_show_presenter.rb', line 239

def 
  Hyrax.config..each_with_object([]) do |field, |
     << {
      'label' => I18n.t("simple_form.labels.defaults.#{field}"),
      'value' => Array.wrap(send(field).map { |f| Loofah.fragment(f.to_s).scrub!(:whitewash).to_s })
    }
  end
end

#manifest_urlObject



221
222
223
# File 'app/presenters/hyrax/work_show_presenter.rb', line 221

def manifest_url
  manifest_helper.polymorphic_url([:manifest, self])
end

#member_countInteger

Returns:

  • (Integer)


250
251
252
# File 'app/presenters/hyrax/work_show_presenter.rb', line 250

def member_count
  @member_count ||= member_presenters.count
end

#member_of_collection_presentersArray<CollectionPresenter>

Get presenters for the collections this work is a member of via the member_of_collections association.

Returns:



132
133
134
135
136
# File 'app/presenters/hyrax/work_show_presenter.rb', line 132

def member_of_collection_presenters
  PresenterFactory.build_for(ids: member_of_authorized_parent_collections,
                             presenter_class: collection_presenter_class,
                             presenter_args: presenter_factory_arguments)
end

#modelObject



205
206
207
# File 'app/presenters/hyrax/work_show_presenter.rb', line 205

def model
  solr_document.to_model
end

#page_titleObject



67
68
69
# File 'app/presenters/hyrax/work_show_presenter.rb', line 67

def page_title
  "#{human_readable_type} | #{title.first} | ID: #{id} | #{I18n.t('hyrax.product_name')}"
end

#presenter_typesObject



175
176
177
# File 'app/presenters/hyrax/work_show_presenter.rb', line 175

def presenter_types
  Hyrax.config.registered_curation_concern_types.map(&:underscore) + ["collection"]
end

#representative_presenterObject

Returns FileSetPresenter presenter for the representative FileSets.

Returns:

  • FileSetPresenter presenter for the representative FileSets



117
118
119
120
121
122
123
124
125
126
127
128
# File 'app/presenters/hyrax/work_show_presenter.rb', line 117

def representative_presenter
  return nil if representative_id.blank?
  @representative_presenter ||=
    begin
      result = member_presenters([representative_id]).first
      return nil if result.try(:id) == id
      result.try(:representative_presenter) || result
    rescue Hyrax::ObjectNotFoundError
      Hyrax.logger.warn "Unable to find representative_id #{representative_id} for work #{id}"
      return nil
    end
end

#schema_versionObject



63
64
65
# File 'app/presenters/hyrax/work_show_presenter.rb', line 63

def schema_version
  solr_document[:schema_version_ssi]
end

#sequence_renderingArray

IIIF rendering linking property for inclusion in the manifest Called by the iiif_manifest gem to add a 'rendering' (eg. a link a download for the resource)

Returns:

  • (Array)

    array of rendering hashes



229
230
231
232
233
# File 'app/presenters/hyrax/work_show_presenter.rb', line 229

def sequence_rendering
  solr_document.rendering_ids.each_with_object([]) do |file_set_id, renderings|
    renderings << manifest_helper.build_rendering(file_set_id)
  end.flatten
end

#show_deposit_for?(collections:) ⇒ Boolean

Given a set of collections, which the caller asserts the current ability can deposit to, decide whether to display actions to add this work to a collection.

By default, this returns true if any collections are passed in OR the current ability can create a collection.

Parameters:

  • collections (Enumerable<::Collection>, nil)

    list of collections to which the current ability can deposit

Returns:

  • (Boolean)

    a flag indicating whether to display collection deposit options.



267
268
269
270
# File 'app/presenters/hyrax/work_show_presenter.rb', line 267

def show_deposit_for?(collections:)
  collections.present? ||
    current_ability.can?(:create_any, Hyrax.config.collection_class)
end

#stats_pathObject



201
202
203
# File 'app/presenters/hyrax/work_show_presenter.rb', line 201

def stats_path
  Hyrax::Engine.routes.url_helpers.stats_work_path(self, locale: I18n.locale)
end

#total_pagesInteger

Returns total number of pages of viewable items.

Returns:

  • (Integer)

    total number of pages of viewable items



217
218
219
# File 'app/presenters/hyrax/work_show_presenter.rb', line 217

def total_pages
  (total_items.to_f / rows_from_params.to_f).ceil
end

#tweeterObject



171
172
173
# File 'app/presenters/hyrax/work_show_presenter.rb', line 171

def tweeter
  TwitterPresenter.twitter_handle_for(user_key: depositor)
end

#valid_child_concernsArray<Class>

Returns:

  • (Array<Class>)


274
275
276
# File 'app/presenters/hyrax/work_show_presenter.rb', line 274

def valid_child_concerns
  Hyrax::ChildTypes.for(parent: solr_document.hydra_model).to_a
end

#valkyrie_presenter?Boolean

Returns:

  • (Boolean)


279
280
281
# File 'app/presenters/hyrax/work_show_presenter.rb', line 279

def valkyrie_presenter?
  solr_document.hydra_model < Valkyrie::Resource
end

#work_featurable?Boolean

Returns:

  • (Boolean)


189
190
191
# File 'app/presenters/hyrax/work_show_presenter.rb', line 189

def work_featurable?
  user_can_feature_works? && solr_document.public?
end

#workflowObject



71
72
73
# File 'app/presenters/hyrax/work_show_presenter.rb', line 71

def workflow
  @workflow ||= WorkflowPresenter.new(solr_document, current_ability)
end