Class: Hyrax::Workflow::WorkflowSchema

Inherits:
Dry::Validation::Contract
  • Object
show all
Defined in:
app/services/hyrax/workflow/workflow_schema.rb

Overview

Responsible for describing the JSON schema for a Workflow.

The workflows name defines the name of the Sipity::Workflow. The workflows actions defines the actions that can be taken in the given states (e.g. :from_states) by the given :roles. The workflows actions transition_to defines the state to which we transition when the action is taken. The workflows actions notifications defines the notifications that should be sent when the action is taken.

See Also:

Defined Under Namespace

Classes: Types